diff --git a/src/vector/index.html b/src/vector/index.html
index 14efb0b201..36047aca7a 100644
--- a/src/vector/index.html
+++ b/src/vector/index.html
@@ -27,8 +27,7 @@
if (match) {
var title = match[1].charAt(0).toUpperCase() + match[1].slice(1);
%>
-
+
<% } else { %>
<% }
diff --git a/src/vector/index.js b/src/vector/index.js
index 4a44cbdc5f..5e3718eada 100644
--- a/src/vector/index.js
+++ b/src/vector/index.js
@@ -294,8 +294,8 @@ async function loadApp() {
const match = href.match(/^bundles\/.*\/theme-(.*)\.css$/);
if (match) {
if (match[1] === (configJson.default_theme || 'light')) {
- // remove the alternative flag off the stylesheet
- a.setAttribute("rel", "stylesheet");
+ // remove the disabled flag off the stylesheet
+ a.removeAttribute("disabled");
}
}
}